Type: Package
Package: login
Title: 'shiny' Login Module
Version: 0.9.3
Date: 2024-04-17
Authors@R: 
    person("Jason", "Bryer", , "jason@bryer.org", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-2454-0402"))
Maintainer: Jason Bryer <jason@bryer.org>
Description: Framework for adding authentication to 'shiny' applications.
    Provides flexibility as compared to other options for where user
    credentials are saved, allows users to create their own accounts, and
    password reset functionality. Bryer (2024)
    <doi:10.5281/zenodo.10987876>.
License: GPL (>= 3)
URL: https://github.com/jbryer/login, https://jbryer.github.io/login/
BugReports: https://github.com/jbryer/login/issues
Imports: cookies, DBI, digest, emayili, htmltools, shiny, shinybusy,
        shinyjs, stringr, utils
Suggests: knitr, rmarkdown
Enhances: RSQLite
VignetteBuilder: knitr
Encoding: UTF-8
RoxygenNote: 7.3.1
NeedsCompilation: no
Packaged: 2024-04-18 16:08:38 UTC; jbryer
Author: Jason Bryer [aut, cre] (<https://orcid.org/0000-0002-2454-0402>)
Repository: CRAN
Date/Publication: 2024-04-18 19:32:48 UTC
Built: R 4.6.0; ; 2026-04-29 21:08:25 UTC; unix
