reset_password_from_email <- 'admin@daacs.net'
reset_password_subject <- 'Reset password for msdsdashboard.daacs.net'
email_host <- "smtp.gmail.com"
email_port <- 465
email_username <- "admin@daacs.net"
email_password <- "plifakrsqhvhbkko"
